@@ -805,19 +805,21 @@ class RepresentationDefinition(WADLResolvableDefinition, HasParametersMixin):
         elif media_type == 'multipart/form-data':
             outer = MIMEMultipart()
             outer.set_type('multipart/form-data')
+            missing = object()
             for param in params:
-                value = validated_values[param.name]
-                if param.type == 'binary':
-                    maintype, subtype = 'application', 'octet-stream'
-                    params = {}
-                else:
-                    maintype, subtype = 'text', 'plain'
-                    params = {'charset' : 'utf-8'}
-                inner = MIMENonMultipart(maintype, subtype, **params)
-                inner.set_payload(value)
-                inner['Content-Disposition'] = (
-                    'form-data; name="%s"' % param.name)
-                outer.attach(inner)
+                value = validated_values.get(param.name, missing)
+                if value is not missing:
+                    if param.type == 'binary':
+                        maintype, subtype = 'application', 'octet-stream'
+                        params = {}
+                    else:
+                        maintype, subtype = 'text', 'plain'
+                        params = {'charset' : 'utf-8'}
+                    inner = MIMENonMultipart(maintype, subtype, **params)
+                    inner.set_payload(value)
+                    inner['Content-Disposition'] = (
+                        'form-data; name="%s"' % param.name)
+                    outer.attach(inner)
             doc = str(outer)
             # Chop off the 'From' line, which only makes sense in an
             # email.
